==> python-mistune-2.0.0rc1-1-any.pkg.tar.xz: usr/share/doc/python-mistune/README.md <==
<a href="https://github.com/lepture/mistune">
<img align="right" width="120" height="120" src="docs/_static/logo.svg">
</a>

# Mistune v2

A fast yet powerful Python Markdown parser with renderers and plugins.

<a href="https://lepture.com/donate"><img src="https://badgen.net/badge/donate/lepture/ff69b4?icon=patreon" /></a>
<a href="https://github.com/lepture/mistune/actions"><img src="https://github.com/lepture/mistune/workflows/tests/badge.svg" /></a>
<a href="https://codecov.io/gh/lepture/mistune"><img src="https://badgen.net/codecov/c/github/lepture/mistune" alt="Coverage"></a>


**NOTE: This is the re-designed v2 of mistune. Check `v1` branch for earlier code.**

Using old Mistune? Checkout docs: <https://mistune.readthedocs.io/en/v0.8.4/>

## Sponsors

<table>
<tr>
<td><img align="middle" width="64" src="https://typlog.com/android-chrome-512x512.png"></td>
<td>Mistune is sponsored by Typlog, a blogging and podcast hosting platform, simple yet powerful. <a href="https://typlog.com/?utm_source=mistune&utm_medium=referral&utm_campaign=readme">Write in Markdown</a>.
</td>
</tr>
</table>

[**Support Me via GitHub Sponsors**](https://github.com/users/lepture/sponsorship).

## Install

To install v2 of mistune:

```
$ pip install mistune==2.0.0rc1
```

## Overview

Convert Markdown to HTML with ease:

```python
import mistune

mistune.html(your_markdown_text)
```

## Security Reporting

If you found security bugs, please do not send a public issue or patch.
You can send me email at <me@lepture.com>. Attachment with patch is welcome.
My PGP Key fingerprint is:

```
72F8 E895 A70C EBDF 4F2A DFE0 7E55 E3E0 118B 2B4C
```

Or, you can use the [Tidelift security contact](https://tidelift.com/security).
Tidelift will coordinate the fix and disclosure.

## License

Mistune is licensed under BSD. Please see LICENSE for licensing details.

==> python-mistune-2.0.2-1-any.pkg.tar.xz: usr/share/doc/python-mistune/README.md <==
<a href="https://github.com/lepture/mistune">
<img align="right" width="120" height="120" src="docs/_static/logo.svg">
</a>

# Mistune v2

A fast yet powerful Python Markdown parser with renderers and plugins.

<a href="https://lepture.com/donate"><img src="https://badgen.net/badge/donate/lepture/ff69b4?icon=patreon" /></a>
<a href="https://github.com/lepture/mistune/actions"><img src="https://github.com/lepture/mistune/workflows/tests/badge.svg" /></a>
<a href="https://codecov.io/gh/lepture/mistune"><img src="https://badgen.net/codecov/c/github/lepture/mistune" alt="Coverage"></a>


**NOTE: This is the re-designed v2 of mistune. Check `v1` branch for earlier code.**

Using old Mistune? Checkout docs: <https://mistune.readthedocs.io/en/v0.8.4/>

## Sponsors

<table>
<tr>
<td><img align="middle" width="64" src="https://typlog.com/android-chrome-512x512.png"></td>
<td>Mistune is sponsored by Typlog, a blogging and podcast hosting platform, simple yet powerful. <a href="https://typlog.com/?utm_source=mistune&utm_medium=referral&utm_campaign=readme">Write in Markdown</a>.
</td>
</tr>
</table>

[**Support Me via GitHub Sponsors**](https://github.com/users/lepture/sponsorship).

## Install

To install mistune:

```
$ pip install mistune
```

## Overview

Convert Markdown to HTML with ease:

```python
import mistune

mistune.html(your_markdown_text)
```

## Security Reporting

If you found security bugs, please do not send a public issue or patch.
You can send me email at <me@lepture.com>. Attachment with patch is welcome.
My PGP Key fingerprint is:

```
72F8 E895 A70C EBDF 4F2A DFE0 7E55 E3E0 118B 2B4C
```

Or, you can use the [Tidelift security contact](https://tidelift.com/security).
Tidelift will coordinate the fix and disclosure.

## License

Mistune is licensed under BSD. Please see LICENSE for licensing details.
